@@ -1,14 +1,20 @@
 ## ----example1------------------------------------------------------------
-library(BatchGetSymbols, quietly = T)
+if (!require(BatchGetSymbols)) install.packages('BatchGetSymbols')
 
-first.date <- Sys.Date()-15
+library(BatchGetSymbols)
+
+# set dates
+first.date <- Sys.Date() - 60
 last.date <- Sys.Date()
 
-tickers <- c('FB','NYSE:MMM','abcdef')
+# set tickers
+tickers <- c('FB','NYSE:MMM','PETR4.SA','abcdef')
 
-l.out <- BatchGetSymbols(tickers = tickers,
+l.out <- BatchGetSymbols(tickers = tickers, 
                          first.date = first.date,
-                         last.date = last.date)
+                         last.date = last.date, 
+                         cache.folder = file.path(tempdir(), 
+                                                  'BGS_Cache') ) # cache in tempdir()
 
 
 ## ----example2------------------------------------------------------------
@@ -18,8 +24,9 @@ print(l.out$df.control)
 ## ----plot.prices, fig.width=7, fig.height=2.5----------------------------
 library(ggplot2)
  
-p <- ggplot(l.out$df.tickers, aes(x = ref.date, y = price.close, color = ticker))
-p <-  p + geom_line()
+p <- ggplot(l.out$df.tickers, aes(x = ref.date, y = price.close))
+p <- p + geom_line()
+p <- p + facet_wrap(~ticker, scales = 'free_y') 
 print(p)
 
 ## ----example3,eval=FALSE-------------------------------------------------
